==> haskell-skylighting-format-context-0.1.0.2-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-KQGww8rovSBBtkjJOSnUiO
key:                  skylighting-format-context-0.1.0.2-KQGww8rovSBBtkjJOSnUiO
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  737d750511a3069467f7229e9c370ba3
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-KQGww8rovSBBtkjJOSnUiO
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.2-7og0O7cZBFa3AFgOI6M5IO text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-context-0.1.0.2-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-8GTgVu5gPvt72vXmq06vPk
key:                  skylighting-format-context-0.1.0.2-8GTgVu5gPvt72vXmq06vPk
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  a7030348cdbc999e116f5196a67b2a1e
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-8GTgVu5gPvt72vXmq06vPk
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.2-68IvbucFBVnB6KXoJAAGZy text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
